@@ -37,6 +37,10 @@ def _parse_connect_response(sock: Socket) -> Tuple[Optional[int], str]:
     return status, "\n".join(lines)
 
 
+def _use_or_create_ssl_context(ssl_context: Optional[ssl.SSLContext] = None):
+    return ssl_context if ssl_context is not None else ssl.create_default_context()
+
+
 def _establish_new_socket_connection(
     session_id: str,
     server_hostname: str,
@@ -47,7 +51,11 @@ def _establish_new_socket_connection(
     proxy: Optional[str],
     proxy_headers: Optional[Dict[str, str]],
     trace_enabled: bool,
+    ssl_context: Optional[ssl.SSLContext] = None,
 ) -> Union[ssl.SSLSocket, Socket]:
+
+    ssl_context = _use_or_create_ssl_context(ssl_context)
+
     if proxy is not None:
         parsed_proxy = urlparse(proxy)
         proxy_host, proxy_port = parsed_proxy.hostname, parsed_proxy.port or 80
@@ -59,9 +67,7 @@ def _establish_new_socket_connection(
         message = [f"CONNECT {server_hostname}:{server_port} HTTP/1.0"]
         if parsed_proxy.username is not None and parsed_proxy.password is not None:
             # In the case where the proxy is "http://{username}:{password}@{hostname}:{port}"
-            raw_value = (
-                f"{unquote(parsed_proxy.username)}:{unquote(parsed_proxy.password)}"
-            )
+            raw_value = f"{unquote(parsed_proxy.username)}:{unquote(parsed_proxy.password)}"
             auth = b64encode(raw_value.encode("utf-8")).decode("ascii")
             message.append(f"Proxy-Authorization: Basic {auth}")
         if proxy_headers is not None:
@@ -79,11 +85,9 @@ def _establish_new_socket_connection(
             log_message = f"Proxy connect response (session id: {session_id}):\n{text}"
             logger.debug(log_message)
         if status != 200:
-            raise Exception(
-                f"Failed to connect to the proxy (proxy: {proxy}, connect status code: {status})"
-            )
+            raise Exception(f"Failed to connect to the proxy (proxy: {proxy}, connect status code: {status})")
 
-        sock = ssl.create_default_context().wrap_socket(
+        sock = ssl_context.wrap_socket(
             sock,
             do_handshake_on_connect=True,
             suppress_ragged_eofs=True,
@@ -93,14 +97,12 @@ def _establish_new_socket_connection(
 
     if server_port != 443:
         # only for library testing
-        logger.info(
-            f"Using non-ssl socket to connect ({server_hostname}:{server_port})"
-        )
+        logger.info(f"Using non-ssl socket to connect ({server_hostname}:{server_port})")
         sock = socket.create_connection((server_hostname, server_port), timeout=3)
         return sock
 
     sock = socket.create_connection((server_hostname, server_port), receive_timeout)
-    sock = ssl.create_default_context().wrap_socket(
+    sock = ssl_context.wrap_socket(
         sock,
         do_handshake_on_connect=True,
         suppress_ragged_eofs=True,
@@ -195,11 +197,7 @@ def _receive_messages(
     all_message_trace_enabled: bool = False,
 ) -> List[Tuple[Optional[FrameHeader], bytes]]:
     def receive(specific_buffer_size: Optional[int] = None):
-        size = (
-            specific_buffer_size
-            if specific_buffer_size is not None
-            else receive_buffer_size
-        )
+        size = specific_buffer_size if specific_buffer_size is not None else receive_buffer_size
         with sock_receive_lock:
             try:
                 received_bytes = sock.recv(size)
@@ -389,9 +387,7 @@ def _build_data_frame_for_sending(
     b1 = fin << 7 | rsv1 << 6 | rsv2 << 5 | rsv3 << 4 | opcode
     header: bytes = bytes([b1])
 
-    original_payload_data: bytes = (
-        payload.encode("utf-8") if isinstance(payload, str) else payload
-    )
+    original_payload_data: bytes = payload.encode("utf-8") if isinstance(payload, str) else payload
     payload_length = len(original_payload_data)
     if payload_length <= 125:
         b2 = masked << 7 | payload_length
@@ -403,8 +399,5 @@ def _build_data_frame_for_sending(
     mask_key: List[int] = random.choices(range(256), k=4)
     header += bytes(mask_key)
 
-    payload_data: bytes = bytes(
-        byte ^ mask
-        for byte, mask in zip(original_payload_data, itertools.cycle(mask_key))
-    )
+    payload_data: bytes = bytes(byte ^ mask for byte, mask in zip(original_payload_data, itertools.cycle(mask_key)))
     return header + payload_data
