@@ -73,16 +73,12 @@ class AsyncBaseClient:
         `http_proxy` environment variables."""
         self.headers = headers or {}
         """`dict` representing additional request headers to attach to all requests."""
-        self.headers["User-Agent"] = get_user_agent(
-            user_agent_prefix, user_agent_suffix
-        )
+        self.headers["User-Agent"] = get_user_agent(user_agent_prefix, user_agent_suffix)
         self.default_params = {}
         if team_id is not None:
             self.default_params["team_id"] = team_id
         self._logger = logger if logger is not None else logging.getLogger(__name__)
-        self.retry_handlers = (
-            retry_handlers if retry_handlers is not None else async_default_handlers()
-        )
+        self.retry_handlers = retry_handlers if retry_handlers is not None else async_default_handlers()
 
         if self.proxy is None or len(self.proxy.strip()) == 0:
             env_variable = load_http_proxy_from_env(self._logger)
@@ -168,9 +164,7 @@ class AsyncBaseClient:
             req_args=req_args,
         )
 
-    async def _send(
-        self, http_verb: str, api_url: str, req_args: dict
-    ) -> AsyncSlackResponse:
+    async def _send(self, http_verb: str, api_url: str, req_args: dict) -> AsyncSlackResponse:
         """Sends the request out for transmission.
 
         Args:
@@ -193,9 +187,7 @@ class AsyncBaseClient:
                 # True/False -> "1"/"0"
                 req_args["params"] = convert_bool_to_0_or_1(req_args["params"])
 
-            res = await self._request(
-                http_verb=http_verb, api_url=api_url, req_args=req_args
-            )
+            res = await self._request(http_verb=http_verb, api_url=api_url, req_args=req_args)
         finally:
             for f in open_files:
                 f.close()
